"""Scrapy scrapers for each on-line database."""

# The version of the JSON data structure used to represent the checklist.
DOWNLOAD_FORMAT = 1

# The default ISO 639-1 Code for the language used in the file.
DOWNLOAD_LANGUAGE = 'en'
